use actix_web::{web, HttpResponse, Responder};
use serde_json::json;
use sqlx::PgPool;

use crate::{
    endpoints::IdPath,
    mail::Mailer,
    models::{Registration, Role, User},
    utils::ApplicationError,
};

#[actix_web::post("/users/{id}/resend-registration")]
pub async fn post(
    user: web::ReqData<User>,
    pool: web::Data<PgPool>,
    path: web::Path<IdPath>,
    mailer: web::Data<Mailer>,
) -> Result<impl Responder, ApplicationError> {
    if user.role != Role::AreaManager && user.role != Role::Admin {
        return Err(ApplicationError::Unauthorized);
    }

    let Some(user_in_db) = User::read_by_id(pool.get_ref(), path.id).await? else {
        return Ok(HttpResponse::NotFound().finish());
    };

    if user.role == Role::AreaManager && user.area_id != user_in_db.area_id {
        return Err(ApplicationError::Unauthorized);
    }

    if user_in_db.password.is_some() || user_in_db.salt.is_some() || user_in_db.last_login.is_some()
    {
        return Ok(HttpResponse::BadRequest().finish());
    }

    Registration::delete_all_for_user(pool.get_ref(), user_in_db.id).await?;
    let registration = Registration::insert_new_for_user(pool.get_ref(), user_in_db.id).await?;
    mailer
        .send_registration_mail(&user_in_db, &registration.token)
        .await?;

    let trigger = json!({
        "showToast": {
            "type": "success",
            "message": "Registrierungsmail erfolgreich versendet!"
        }
    })
    .to_string();

    Ok(HttpResponse::NoContent()
        .insert_header(("HX-TRIGGER", trigger))
        .finish())
}
