use maud::html;

use crate::models::UserFunction;

pub fn show_area_query(a: &Option<i32>, first: bool) -> rinja::Result<String> {
    let char = if first { '?' } else { '&' };

    if let Some(a) = a {
        Ok(format!("{}area={}", char, a))
    } else {
        Ok(String::new())
    }
}

pub fn cond_show(show: &bool, text: &str) -> rinja::Result<String> {
    if *show {
        Ok(String::from(text))
    } else {
        Ok(String::new())
    }
}

pub fn insert_value(option: &Option<String>) -> rinja::Result<String> {
    if let Some(val) = option {
        let s = format!(r#"value="{val}""#);
        return Ok(s);
    }

    Ok(String::new())
}

pub fn is_some_and_eq<T>(option: &Option<T>, other: &T) -> rinja::Result<bool>
where
    T: Eq,
{
    Ok(option.as_ref().is_some_and(|x| x == other))
}

pub fn invert(b: &bool) -> rinja::Result<bool> {
    Ok(!b)
}

pub fn show_tree(f: &UserFunction) -> rinja::Result<String> {
    let html = html! {
        div class="tags" {
            @if f.is_posten() {
                span class="tag is-primary is-light" { "Posten"}
            }
            @if f.is_wachhabender() {
                span class="tag is-primary has-background-primary-85 has-text-primary-85-invert" { "Wachhabender"}
            }
            @if f.is_fuehrungsassistent() {
                span class="tag is-primary" { "Führungsassistent"}
            }
        }
    };

    Ok(html.into_string())
}
